use crate::innerlude::*;

pure_props! {
    /// Bulma [Box](https://bulma.io/documentation/elements/box/) Element
    pub struct Box {}
}

pure_wrapper!(Box: <div class="box"/>);
